@@ -1,6 +1,7 @@
 package Text::Forge;
 # ABSTRACT: Templates with embedded Perl
 
+
 #{{{ test
 
 
@@ -17,7 +18,7 @@ use File::Spec ();
 use HTML::Entities ();
 use URI::Escape ();
 
-our $VERSION = '6.01';
+our $VERSION = '6.02';
 
 our @FINC = ('.'); # default search paths
 our %FINC; # compiled template cache
@@ -536,8 +537,6 @@ use Method::Alias trap_send => 'run';
 
 1;
 
-__END__
-
 =pod
 
 =encoding UTF-8
@@ -548,7 +547,7 @@ Text::Forge - Templates with embedded Perl
 
 =head1 VERSION
 
-version 6.01
+version 6.02
 
 =head1 SYNOPSIS
 
@@ -576,20 +575,20 @@ The following tags are supported:
   <%  %> code block (no output)
   <%= %> interpolate, result is HTML escaped
   <%? %> interpolate, result is URI escaped
-  <%$ %> interpolate, no escaping (use with care)
+  <%$ %> interpolate, no escaping (let's be careful)
   <%# %> comment
 
 All blocks are evaluated within the same lexical scope (so my
 variables declared in one block are visible in subsequent blocks).
 
-Code blocks contain straight perl code. It is executed, but nothing
+Code blocks contain straight Perl code; it is executed, but nothing
 is output.
 
 Interpolation blocks are evaluated and the result inserted into
 the template.
 
-Templates are compiled into normal Perl methods. As such, they can
-be passed arguments as you would expect.
+Templates are compiled into normal Perl methods. They can
+be passed arguments, as you might expect:
 
   print $forge->run(
     \'<% my %args = @_ %>Name is <%= $args{name} %>',
@@ -598,18 +597,18 @@ be passed arguments as you would expect.
 
 The $self variable is available within all templates, and is a reference
 to the Text::Forge instance that is generating the document. This allows
-subclasses to provide customization and context to the templates.
-
-If a block is followed solely by whitespace up to the next newline,
-that whitespace (including the newline) will be suppressed from the output.
-If you really want a newline, add another newline after the block.
-The idea is that the blocks themselves shouldn't affect the formatting.
+subclasses to provide customization and context to templates.
 
 Anything printed to standard output (STDOUT) becomes part of the template.
 
 Any errors in compiling or executing a template raises an exception.
 Errors should correctly reference the template line causing the problem.
 
+If a block is followed solely by whitespace up to the next newline,
+that whitespace (including the newline) will be suppressed from the output.
+If you really want a newline, add another newline after the block.
+The idea is that the blocks themselves shouldn't affect the formatting.
+
 =for testing   use_ok $CLASS;
 
 =begin testing
@@ -1023,7 +1022,7 @@ are passed to the template.
 
   my $content = $forge->run('path/to/my/template', name => 'foo');
 
-If a path is supplied but is not absolute, it will be searched for within
+If a path is supplied and is not absolute, it will be searched for within
 the list of L</search_paths>.
 
 The generated output is returned.
@@ -1033,11 +1032,10 @@ The generated output is returned.
   my $forge = Text::Forge->new;
   $forge->cache(1);
 
-Dictates whether templates should be cached. Defaults to true.
+Specifies whether templates should be cached. Defaults to true.
 
 If caching is enabled, templates are compiled into subroutines once and
-then reused. Cached templates will not reflect changes to the underlying
-template files.
+then reused.
 
 If you want to ensure templates always reflect the latest changes
 on disk (such as during development), set cache() to false.
@@ -1057,8 +1055,10 @@ Defaults to Unicode (utf8).
 The list of directories to search for relative template paths.
 
   my $forge = Text::Forge->new;
-  $forge->search_paths('/home/app/templates', '.');
-  $forge->run('header'); # looks for /home/app/templates/header and ./header
+  $forge->search_paths('/app/templates', '.');
+
+  # will look for /app/templates/header and ./header
+  $forge->run('header');
 
 =head2 content
 
@@ -1097,32 +1097,34 @@ For example:
            <% } %>
          </ul>
     <% }) %>
+
     <h1>Title</h1>
     <%$ $pagination %>
     Results...
     <%$ $pagination %>
   ');
 
-In this case the "pagination" content has been "captured" into the variable
-$pagination, which is then inserted in multiple locations within the
-main template.
+In this case the "pagination" content has been captured into the variable
+$pagination, which is then inserted in multiple locations elsewhere in
+the document.
 
 =head2 content_for 
 
-Capture the output into a named placeholder. Same as capture() except the
+Capture the output into a named placeholder. Same as L</capture> except the
 result in stored internally as $forge->{captures}{ $name }.
 
 Note that multiple calls to content_for() with the same name are concatenated
-together (not overwritten); this allows, for example, to have multiple calls
-to something like content_for('head', ...) in various places, which are
-aggregated together and inserted at the head of the document.
+together (not overwritten); this allows, for example, multiple calls
+to something like content_for('head', ...), which are then aggregated and
+inserted elsewhere in the document.
 
-When called With two arguments, this method stores the specified content in
+When called with two arguments, this method stores the specified content in
 the named location:
 
   my $forge = Text::Forge->new;
   $forge->run(\'
     <h1>Title</h1>
+
     <% $self->capture_for('nav', sub { %>
          <ul>
            <li>...</li>
@@ -1130,7 +1132,7 @@ the named location:
     <% }) %>
   ');
 
-When called with one argument, returns the previously stored content, if any:
+When called with one argument, it returns the previously stored content, if any:
 
   my $nav = $self->content_for('nav');
 
@@ -1139,10 +1141,10 @@ When called with one argument, returns the previously stored content, if any:
 Specifies a layout template to apply. Defaults to none.
 
 If defined, the layout template is applied after the primary template
-is generated. The layout template may then "wrap" the primary template
-in additional content.
+has been generated. The layout template may then "wrap" the primary template
+with additional content.
 
-For example, rather than have each template include() a separate header
+For example, rather than have each template L</include> a separate header
 and footer template explicitly, a layout() template can be used more
 simply:
 
@@ -1156,6 +1158,36 @@ simply:
 Within the layout, the primary template content is available as $_ (as well
 as through $self->content_for('main')).
 
+=head2 escape_html, h
+
+Returns HTML encoded versions of its arguments. This method is used internally
+to encode the result of <%= %> blocks, but can be used directly:
+
+  my $forge = Text::Forge->new;
+  print $forge->run(\'<% print $self->escape_html("<strong>") %>');
+  # outputs: &lt;strong&gt;
+
+The h() method is just an alias for convenience.
+
+If a blessed reference is passed that provides an as_html() method, the
+result of that method will be returned instead. This allows objects to
+be constructed that keep track of their own encoding state.
+
+=head2 escape_uri, u
+
+Returns URI escaped versions of its arguments. This method is used internally
+to encode the result of <%? %> blocks, but can be used directly:
+
+  my $forge = Text::Forge->new;
+  print $forge->run(\'<% print $self->escape_uri("name=foo") %>');
+  # outputs: name%3Dfoo
+
+The u() method is just an alias for convenience.
+
+If a blessed reference is passed that provides an as_uri() method, the
+result of that method will be returned instead. This allows objects to
+be constructed that keep track of their own encoding state.
+
 =head1 AUTHOR
 
 Maurice Aubrey <maurice.aubrey@gmail.com>
@@ -1168,3 +1200,9 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+
+
+# vim: set foldmethod=marker:
